use crate::deser::*;

#[derive(Debug, Clone)]
pub struct TargetOptions<'a> {
    pub inherit: bool,
    pub inherit_from: &'a str,
    pub default: bool,
    pub depend_on: Vec<&'a str>,
}

impl<'a> From<&'a DeserTargetOptions> for TargetOptions<'a> {
    fn from(value: &'a DeserTargetOptions) -> Self {
        let mut ret = Self::get_default();

        if let Some(v) = &value.inherit {
            ret.inherit = *v; // dereference the bool to copy it
        }

        if let Some(v) = &value.inherit_from {
            ret.inherit_from = v;
        }

        if let Some(v) = &value.default {
            ret.default = *v; // dereference the bool to copy it
        }

        if let Some(v) = &value.depend_on {
            for string in v {
                ret.depend_on.push(string);
            }
        }

        ret
    }
}

impl<'a> TargetOptions<'a> {
    pub fn get_default() -> Self {
        Self {
            inherit: true,
            inherit_from: "main",
            default: false,
            depend_on: vec![],
        }
    }
}
